@@ -21,12 +21,6 @@ filename = download_file(
     'http://jsoc.stanford.edu/data/hmi/synoptic/hmi.Synoptic_Mr.2191.fits', cache=True)
 syn_map = sunpy.map.Map(filename)
 
-###############################################################################
-# Change colormap and colormap limits
-
-syn_map.plot_settings['cmap'] = 'hmimag'
-syn_map.plot_settings['norm'] = plt.Normalize(-1500, 1500)
-
 ###############################################################################
 # Plot the results.
 
