@@ -17,21 +17,24 @@ from sunpy.timeseries import TimeSeries
 # data for this time from the NOAA Space Weather Prediction Center (SWPC).
 
 tr = a.Time('2011-06-07 04:00', '2011-06-07 12:00')
-results = Fido.search(tr, a.Instrument.xrs & a.goes.SatelliteNumber(15) | a.hek.FL & (a.hek.FRM.Name == 'SWPC'))
+results = Fido.search(tr, a.Instrument.xrs & a.goes.SatelliteNumber(15) | a.hek.FL & (a.hek.FRM.Name == 'SWPC'))  # NOQA
 
 ###############################################################################
-# Then download the XRS data and load it into a TimeSeries
+# Then download the XRS data and load it into a TimeSeries.
+
 files = Fido.fetch(results)
 goes = TimeSeries(files)
 
 ###############################################################################
 # Next let's retrieve `~sunpy.net.hek.HEKTable` from the Fido result
 # and then load the first row from HEK results into ``flares_hek``.
+
 hek_results = results['hek']
 flares_hek = hek_results[0]
 
 ###############################################################################
 # Lets plot everything together.
+
 fig, ax = plt.subplots()
 goes.plot()
 ax.axvline(parse_time(flares_hek['event_peaktime']).datetime)
@@ -40,4 +43,5 @@ ax.axvspan(parse_time(flares_hek['event_starttime']).datetime,
            alpha=0.2, label=flares_hek['fl_goescls'])
 ax.legend(loc=2)
 ax.set_yscale('log')
+
 plt.show()
