@@ -17,18 +17,17 @@ import sunpy.map
 from sunpy.net import Fido
 from sunpy.net import attrs as a
 
-##############################################################################
-# The first step is to download some data, we are going to get an image from
-# early 2011 when the STEREO spacecraft were roughly 90 deg separated from the
-# Earth.
+###############################################################################
+# The first step is to download some data. We download an image from STEREO-A
+# and an image from SDO, which are separated in longitude.
 
-stereo = (a.Source('STEREO_B') &
+stereo = (a.Source('STEREO_A') &
           a.Instrument("EUVI") &
-          a.Time('2011-01-01', '2011-01-01T00:10:00'))
+          a.Time('2021-01-01 00:06', '2021-01-01 00:07'))
 
 aia = (a.Instrument.aia &
        a.Sample(24 * u.hour) &
-       a.Time('2011-01-01', '2011-01-02'))
+       a.Time('2021-01-01 00:06', '2021-01-02 00:06'))
 
 wave = a.Wavelength(30 * u.nm, 31 * u.nm)
 result = Fido.search(wave, aia | stereo)
@@ -46,6 +45,7 @@ print(downloaded_files)
 maps = {m.detector: m.submap(SkyCoord([-1100, 1100], [-1100, 1100],
                                       unit=u.arcsec, frame=m.coordinate_frame))
         for m in sunpy.map.Map(downloaded_files)}
+maps['AIA'].plot_settings['vmin'] = 0  # set the minimum plotted pixel value
 
 ##############################################################################
 # Now, let's plot both maps, and we draw the limb as seen by AIA onto the
@@ -63,22 +63,28 @@ visible, hidden = maps['AIA'].draw_limb()
 hidden.remove()
 
 ##############################################################################
-# Let's also plot the helioprojective coordinate grid as seen by SDO on the
-# STEREO image.
+# Let's plot the helioprojective coordinate grid as seen by SDO on the STEREO
+# image in a cropped view.  Note that only those grid lines that intersect the
+# edge of the plot will have corresponding ticks and tick labels.
 
 fig = plt.figure()
 ax = plt.subplot(projection=maps['EUVI'])
 
 maps['EUVI'].plot()
 
-# Move the title so it does not clash with the extra labels.
-tx, ty = ax.title.get_position()
-ax.title.set_position([tx, ty + 0.08])
+# Crop the view using pixel coordinates
+ax.set_xlim(500, 1300)
+ax.set_ylim(100, 900)
 
-# Change the default grid labels.
+# Shrink the plot slightly and move the title up to make room for new labels.
+ax.set_position([0.1, 0.1, 0.8, 0.7])
+ax.set_title(ax.get_title(), pad=45)
+
+# Change the default grid labels and line properties.
 stereo_x, stereo_y = ax.coords
 stereo_x.set_axislabel("Helioprojective Longitude (STEREO B) [arcsec]")
 stereo_y.set_axislabel("Helioprojective Latitude (STEREO B) [arcsec]")
+ax.coords.grid(color='white', linewidth=1)
 
 # Add a new coordinate overlay in the SDO frame.
 overlay = ax.get_coords_overlay(maps['AIA'].coordinate_frame)
@@ -87,13 +93,17 @@ overlay.grid()
 # Configure the grid:
 x, y = overlay
 
+# Wrap the longitude at 180 deg rather than the default 360.
+x.set_coord_type('longitude', 180.)
+
+# Set the tick spacing
+x.set_ticks(spacing=250*u.arcsec)
+y.set_ticks(spacing=250*u.arcsec)
+
 # Set the ticks to be on the top and left axes.
 x.set_ticks_position('tr')
 y.set_ticks_position('tr')
 
-# Wrap the longitude at 180 deg rather than the default 360.
-x.set_coord_type('longitude', 180.)
-
 # Change the defaults to arcseconds
 x.set_major_formatter('s.s')
 y.set_major_formatter('s.s')
