@@ -102,6 +102,10 @@ class ObserverCoordinateAttribute(CoordinateAttribute):
         if isinstance(value, str):
             return value, False
         else:
+            # Make sure that the coordinate is 3D
+            if hasattr(value, 'make_3d'):
+                value = value.make_3d()
+
             # Upgrade the coordinate to a `SkyCoord` so that frame attributes will be merged
             if isinstance(value, BaseCoordinateFrame) and not isinstance(value, self._frame):
                 value = SkyCoord(value)
@@ -135,7 +139,7 @@ class ObserverCoordinateAttribute(CoordinateAttribute):
             # If the observer is a string and we have obstime then calculate
             # the position of the observer.
             if isinstance(observer, str):
-                if obstime is not None:
+                if observer != "self" and obstime is not None:
                     new_observer = self._convert_string_to_coord(observer.lower(), obstime)
                     new_observer.object_name = observer
                     setattr(instance, '_' + self.name, new_observer)
