@@ -8,10 +8,10 @@ from astropy.time import Time
 
 import sunpy.coordinates.frames as f
 from sunpy.coordinates.metaframes import RotatedSunFrame, _rotatedsun_cache
+from sunpy.coordinates.tests.helpers import assert_longitude_allclose
+from sunpy.coordinates.tests.strategies import latitudes, longitudes, times
 from sunpy.physics.differential_rotation import diff_rot
 from sunpy.sun import constants
-from .helpers import assert_longitude_allclose
-from .strategies import latitudes, longitudes, times
 
 # NorthOffsetFrame is tested in test_offset_frame.py
 
