@@ -4,6 +4,7 @@ import pytest
 import astropy.units as u
 from astropy.constants import c as speed_of_light
 from astropy.coordinates import (
+    HCRS,
     ICRS,
     Angle,
     CartesianDifferential,
@@ -32,7 +33,8 @@ from sunpy.coordinates import (
 )
 from sunpy.coordinates.ephemeris import get_body_heliographic_stonyhurst, get_earth
 from sunpy.coordinates.frames import _J2000
-from sunpy.coordinates.transformations import transform_with_sun_center
+from sunpy.coordinates.transformations import propagate_with_solar_surface, transform_with_sun_center
+from sunpy.physics.differential_rotation import diff_rot
 from sunpy.sun.constants import radius as _RSUN
 from sunpy.sun.constants import sidereal_rotation_rate
 from sunpy.time import parse_time
@@ -170,6 +172,32 @@ def test_hgs_hcrs():
     assert quantity_allclose(earth_hme.distance, 0.9848139*u.AU, atol=5e-7*u.AU)
 
 
+def test_hcrs_hgs_different_obstime():
+    # Test whether the HCRS->HGS transformation handles a change in obstime the same way as forcing
+    # a HCRS loopback in Astropy
+    time1 = Time('2001-01-01')
+    time2 = Time('2001-02-01')
+
+    coord = HCRS(1*u.km, 2*u.km, 3*u.km, representation_type='cartesian', obstime=time1)
+    out_frame = HeliographicStonyhurst(obstime=time2)
+
+    sunpy_coord = coord.transform_to(out_frame)
+    astropy_coord = coord.transform_to(HCRS(obstime=time2)).transform_to(out_frame)
+
+    assert quantity_allclose(sunpy_coord.cartesian.xyz, astropy_coord.cartesian.xyz)
+
+
+def test_hcrs_hgs_reversibility():
+    # Test whether the HCRS->HGS transformation is reversed by the HGS->HCRS transformation
+    time1 = Time('2001-01-01')
+    time2 = Time('2001-02-01')
+
+    coord = HCRS(1*u.km, 2*u.km, 3*u.km, representation_type='cartesian', obstime=time1)
+    new_coord = coord.transform_to(HeliographicStonyhurst(obstime=time2)).transform_to(coord)
+
+    assert quantity_allclose(coord.cartesian.xyz, new_coord.cartesian.xyz)
+
+
 def test_hgs_hgc_roundtrip():
     obstime = "2011-01-01"
 
@@ -344,12 +372,12 @@ def test_hgc_hgc():
                                                                             obstime=obstime))
     new = old.transform_to(HeliographicCarrington(observer='earth', obstime=obstime + 1*u.day))
 
-    assert_quantity_allclose(new.lon, 75.815607 * u.deg, atol=1e-7*u.deg)  # solar rotation
+    assert_quantity_allclose(new.lon, 75.815592 * u.deg, atol=1e-7*u.deg)  # solar rotation
     # These are not equal to the old values, because the coordinates stay fixed
     # in inertial space, whilst the frame (fixed to the center of the Sun)
     # moves slightly.
-    assert_quantity_allclose(new.lat, 9.999963 * u.deg, atol=1e-7*u.deg)
-    assert_quantity_allclose(new.radius, 1.000009 * u.AU, atol=1e-7*u.AU)
+    assert_quantity_allclose(new.lat, 10.000037 * u.deg, atol=1e-7*u.deg)
+    assert_quantity_allclose(new.radius, 0.999991 * u.AU, atol=1e-7*u.AU)
 
 
 def test_hgc_hgc_different_observers():
@@ -907,7 +935,7 @@ def test_transform_with_sun_center():
 
 
 def test_transform_with_sun_center_reset():
-    # This test sequence ensures that the context manager resets propoerly
+    # This test sequence ensures that the context manager resets properly
 
     sun_center = SkyCoord(0*u.deg, 0*u.deg, 0*u.AU,
                           frame=HeliographicStonyhurst(obstime="2001-01-01"))
@@ -940,3 +968,50 @@ def test_transform_with_sun_center_reset():
     assert_quantity_allclose(result3.lon, result1.lon)
     assert_quantity_allclose(result3.lat, result1.lat)
     assert_quantity_allclose(result3.distance, result1.distance)
+
+
+def test_rsun_preservation():
+    # Check that rsun is preserved when transforming between any two frames with that attribute
+    args_in = {'obstime': '2001-01-01', 'rsun': 690*u.Mm}
+    args_out = {'obstime': '2001-02-01', 'rsun': 700*u.Mm}
+
+    coords_in = [Helioprojective(0*u.deg, 0*u.deg, 1*u.AU, observer='earth', **args_in),
+                 HeliographicStonyhurst(0*u.deg, 0*u.deg, 1*u.AU, **args_in),
+                 HeliographicCarrington(0*u.deg, 0*u.deg, 1*u.AU, observer='earth', **args_in)]
+
+    for coord in coords_in:
+        for frame in coords_in:
+            out_coord = coord.transform_to(frame.replicate(**args_out))
+            assert_quantity_allclose(out_coord.rsun, args_out['rsun'])
+
+
+def test_propagate_with_solar_surface():
+    # Test propagating the meridian by 6 days of solar rotation
+    meridian = SkyCoord(0*u.deg, np.arange(0, 90, 10)*u.deg, 1*u.AU,
+                        frame=HeliocentricInertial, obstime='2001-01-01')
+    dt = 6*u.day
+    end_frame = HeliocentricInertial(obstime=meridian.obstime + dt)
+
+    # Without the context manager
+    result1 = meridian.transform_to(end_frame)
+    assert u.allclose(result1.lon, 0*u.deg, atol=1e-1*u.deg)  # no rotation with the solar surface
+    assert not u.allclose(result1.lon, 0*u.deg, atol=1e-3*u.deg)  # some change due to translation
+    assert u.allclose(result1.lat, meridian.lat, atol=1e-2*u.deg)
+
+    # Using the context manager (also test default rotation model is 'howard')
+    with propagate_with_solar_surface():
+        result2 = meridian.transform_to(end_frame)
+    assert u.allclose(result2.lon, diff_rot(dt, meridian.lat, rot_type='howard'))
+
+    # Check that nesting the context manager doesn't confuse anything (also test other models)
+    with propagate_with_solar_surface('snodgrass'):
+        with propagate_with_solar_surface('allen'):
+            pass
+        result3 = meridian.transform_to(end_frame)  # should use 'snodgrass', not 'allen'
+    assert u.allclose(result3.lon, diff_rot(dt, meridian.lat, rot_type='snodgrass'))
+
+    # After the context manager, the coordinate should have the same result as the first transform
+    result4 = meridian.transform_to(end_frame)
+    assert_quantity_allclose(result4.lon, result1.lon)
+    assert_quantity_allclose(result4.lat, result1.lat)
+    assert_quantity_allclose(result4.distance, result1.distance)
