@@ -17,9 +17,9 @@ class DownloaderBase(metaclass=ABCMeta):
 
         Parameters
         ----------
-        url: `str`
+        url : `str`
             URL of the file to be downloaded.
-        path: `pathlib.Path` or `str`
+        path : `pathlib.Path` or `str`
             Path where the file should be downloaded to.
 
         Raises
@@ -38,7 +38,7 @@ class DownloaderError(Exception):
 class ParfiveDownloader(DownloaderBase):
     """
     Concrete implementation of `~sunpy.data.data_manager.downloader.DownloaderBase`
-    using `parfive`.
+    using :mod:`parfive`.
     """
 
     def download(self, url, path):
