@@ -26,7 +26,7 @@ class NoSuchEntryError(Exception):
     def __init__(self, database_entry):
         self.database_entry = database_entry
 
-    def __str__(self):  # pragma: no cover
+    def __str__(self):
         return (
             'the database entry {!r} cannot be removed because it '
             'is not stored in the database'.format(self.database_entry))
@@ -42,7 +42,7 @@ class NonRemovableTagError(Exception):
         self.database_entry = tag
         self.tag = tag
 
-    def __str__(self):  # pragma: no cover
+    def __str__(self):
         errmsg = 'the tag {0} cannot be removed from the database entry {1!r}'
         return errmsg.format(self.database_entry, self.tag)
 
@@ -59,11 +59,11 @@ class DatabaseOperation(ABC):
 
     @abstractmethod
     def __call__(self):
-        return  # pragma: no cover
+        return
 
     @abstractmethod
     def undo(self):
-        return  # pragma: no cover
+        return
 
 
 class CompositeOperation(DatabaseOperation):
