@@ -121,6 +121,23 @@ class TagAlreadyAssignedError(Exception):
         return errmsg.format(self.database_entry, self.tag_name)
 
 
+class PartialFetchError(Exception):
+    """
+    This exception is raised if the number of files returned by the
+    downloader does not match the number expected.
+    """
+
+    def __init__(self, paths, n_expected):
+        self.paths = paths
+        self.n_expected = int(n_expected)
+
+    def __str__(self):
+        return (f"The downloader returned {len(self.paths)} file(s) "
+                f"but {self.n_expected} file(s) were expected.\n"
+                f"Successful downloads: {self.paths}\n"
+                f"Errors: {self.paths.errors}")
+
+
 def split_database(source_database, destination_database, *query_string):
     """
     Queries the source database with the query string, and moves the
@@ -135,7 +152,7 @@ def split_database(source_database, destination_database, *query_string):
     destination_database : `~sunpy.database.database.Database`
         A SunPy `~Database` object. This is the database to which the matched
         entries will be moved.
-    query_string : `list`
+    *query_string : `list`
         A variable number of attributes that are chained together via the
         boolean AND operator. The | operator may be used between attributes
         to express the boolean OR operator.
@@ -411,6 +428,10 @@ class Database:
 
         paths = client.fetch(query_result, path)
 
+        # Unable to handle partial success
+        if len(paths) != len(query_result):
+            raise PartialFetchError(paths, len(query_result))
+
         for (path, block) in zip(paths, query_result):
             qr_entry = tables.DatabaseEntry._from_query_result_block(block)
 
@@ -465,7 +486,7 @@ class Database:
 
         Parameters
         ----------
-        query : `list`
+        *query : `list`
             A variable number of attributes that are chained together via the
             boolean AND operator. The | operator may be used between attributes
             to express the boolean OR operator.
@@ -566,7 +587,7 @@ class Database:
 
         Parameters
         ----------
-        query : `list`
+        *query : `list`
             A variable number of attributes that are chained together via the
             boolean AND operator. The | operator may be used between attributes
             to express the boolean OR operator.
@@ -645,7 +666,6 @@ class Database:
         ------
         TypeError
             If no tags are given.
-
         sunpy.database.TagAlreadyAssignedError
             If at least one of the given tags is already assigned to the given
             database entry.
@@ -730,7 +750,6 @@ class Database:
         database_entries : list
             The list of `~sunpy.database.tables.DatabaseEntry`
             that will be added to the database.
-
         ignore_already_added : bool, optional
             See Database.add
 
@@ -761,7 +780,6 @@ class Database:
         ----------
         database_entry : sunpy.database.tables.DatabaseEntry
             The database entry that will be added to this database.
-
         ignore_already_added : bool, optional
             If True, attempts to add an already existing database entry will
             result in a :exc:`sunpy.database.EntryAlreadyAddedError`.
@@ -789,7 +807,6 @@ class Database:
         ----------
         query_result : list
             The value returned by :meth:`sunpy.net.hek.HEKClient.search`
-
         ignore_already_added : bool
             See :meth:`sunpy.database.Database.add`.
 
@@ -854,7 +871,6 @@ class Database:
         query_result : sunpy.net.vso.VSOQueryResponseTable
             A VSO query response that was returned by the ``query`` method of a
             :class:`sunpy.net.vso.VSOClient` object.
-
         ignore_already_added : bool
             See :meth:`sunpy.database.Database.add`.
 
@@ -874,7 +890,6 @@ class Database:
         query_result : sunpy.net.vso.VSOQueryResponseTable
             A VSO query response that was returned by the ``query`` method of a
             :class:`sunpy.net.vso.VSOClient` object.
-
         ignore_already_added : bool
             See :meth:`sunpy.database.Database.add`.
 
@@ -897,7 +912,6 @@ class Database:
             unified downloader. This is returned by the ``search`` method of a
             :class:`sunpy.net.fido_factory.UnifiedDownloaderFactory`
             object.
-
         ignore_already_added : `bool`
             See :meth:`sunpy.database.Database.add`.
 
@@ -922,22 +936,18 @@ class Database:
         ----------
         path : str
             The directory where to look for FITS files.
-
         recursive : bool, optional
             If True, the given directory will be searched recursively.
             Otherwise, only the given directory and no subdirectories are
             searched. The default is `False`, i.e. the given directory is not
             searched recursively.
-
         pattern : str, optional
             The pattern can be used to filter the list of filenames before the
             files are attempted to be read. The default is to collect all
             files. This value is passed to the function :func:`fnmatch.filter`,
             see its documentation for more information on the supported syntax.
-
         ignore_already_added : bool, optional
             See :meth:`sunpy.database.Database.add`.
-
         time_string_parse_format : str, optional
             Fallback timestamp format which will be passed to
             `~astropy.time.Time.strptime` if `sunpy.time.parse_time` is unable to
@@ -970,7 +980,6 @@ class Database:
             Either a path pointing to a FITS file or an opened file-like
             object. If an opened file object, its mode must be one of the
             following rb, rb+, or ab+.
-
         ignore_already_added : bool, optional
             See :meth:`sunpy.database.Database.add`.
 
