@@ -27,6 +27,7 @@ from sunpy.database import (
     EntryAlreadyUnstarredError,
     EntryNotFoundError,
     NoSuchTagError,
+    PartialFetchError,
     TagAlreadyAssignedError,
     attrs,
     disable_undo,
@@ -450,9 +451,7 @@ def test_add_entry_from_hek_qr(database):
         hek.attrs.EventType('FL'))
     assert len(database) == 0
     database.add_from_hek_query_result(hek_res)
-    # This number loves to change, so we are just going to test that it's added
-    # *something*
-    assert len(database) > 1
+    assert len(database) == 90
 
 
 @pytest.mark.remote_data
@@ -1040,6 +1039,22 @@ def test_fetch_separate_filenames():
     shutil.rmtree(tmp_test_dir)
 
 
+@pytest.mark.remote_data
+def test_fetch_partial_download(mocker, database, download_query, tmpdir):
+    results = Results()
+    results.append("successful_download.fits")
+    results.add_error("unsuccessful_download.fits", "https://timeout.invalid", "Timeout Error")
+    mocker.patch("sunpy.net.vso.VSOClient.fetch", return_value=results)
+    path = str(tmpdir.join('{file}.fits'))
+    with pytest.raises(PartialFetchError) as e:
+        database.fetch(*download_query, path=path)
+    successes, failures = str(e.value).split("Errors: ")
+    assert "successful_download.fits" in successes
+    assert "unsuccessful_download.fits" in failures
+    assert "https://timeout.invalid" in failures
+    assert "Timeout Error" in failures
+
+
 @pytest.mark.remote_data
 def test_disable_undo(database, download_query, tmpdir):
     entry = DatabaseEntry()
