@@ -296,7 +296,7 @@ def test_entries_from_file():
         FitsHeaderEntry('NBREG', 1),
         FitsHeaderEntry('NBLAMBD', 1),
         FitsHeaderEntry('WAVELNTH', 6563),
-        FitsHeaderEntry('WAVEUNIT', 'angstrom'),
+        FitsHeaderEntry('WAVEUNIT', -10),
         FitsHeaderEntry('POLARANG', 0),
         FitsHeaderEntry('THEMISFF', 3),
         FitsHeaderEntry('LONGTRC', 258.78),
@@ -371,7 +371,7 @@ def test_entries_from_dir():
         FitsHeaderEntry('DATE_OBS', '2012-07-01T09:10:58.200Z'),
         FitsHeaderEntry('DATE_END', '2012-07-01T09:10:58.200Z'),
         FitsHeaderEntry('WAVELNTH', 1.98669),
-        FitsHeaderEntry('WAVEUNIT', 'm'),
+        FitsHeaderEntry('WAVEUNIT', 0),
         FitsHeaderEntry('PHYSPARA', 'STOKESI'),
         FitsHeaderEntry('OBJECT', 'FS'),
         FitsHeaderEntry('OBS_TYPE', 'RADIO'),
@@ -426,7 +426,7 @@ def test_entries_from_dir_recursively_true():
         entries = list(entries_from_dir(testdir, True,
                                         default_waveunit='angstrom',
                                         time_string_parse_format='%d/%m/%Y'))
-    assert len(entries) == 93
+    assert len(entries) == 91
 
 
 def test_entries_from_dir_recursively_false():
@@ -434,7 +434,7 @@ def test_entries_from_dir_recursively_false():
         entries = list(entries_from_dir(testdir, False,
                                         default_waveunit='angstrom',
                                         time_string_parse_format='%d/%m/%Y'))
-    assert len(entries) == 72
+    assert len(entries) == 70
 
 
 @pytest.mark.remote_data
@@ -462,117 +462,72 @@ def test_entry_from_query_results_with_none_wave(qr_with_none_waves):
 def test_entry_from_query_results_with_none_wave_and_default_unit(
         qr_with_none_waves):
     entries = list(entries_from_query_result(qr_with_none_waves, 'nm'))
-    assert len(entries) == 10
     expected = [
+        DatabaseEntry(
+            source='SOHO', provider='SDAC', physobs='intensity',
+            fileid='/archive/soho/private/data/processed/virgo/tsi_full/VIRGO_TSI_daily_hourly.zip',
+            observation_time_start=datetime(1995, 12, 2, 0, 0),
+            observation_time_end=datetime(2020, 1, 1, 0, 0),
+            instrument='VIRGO', size=13506.0),
+        DatabaseEntry(
+            source='SOHO', provider='SDAC', physobs='intensity',
+            fileid='/archive/soho/private/data/processed/virgo/spm/VIRGO-SPM-BLUE-L2-MISSIONLONG.fits',
+            observation_time_start=datetime(1996, 1, 23, 0, 0),
+            observation_time_end=datetime(2021, 5, 15, 23, 59),
+            instrument='VIRGO', size=32652.0),
+        DatabaseEntry(
+            source='SOHO', provider='SDAC', physobs='intensity',
+            fileid='/archive/soho/private/data/processed/virgo/spm/VIRGO-SPM-GREEN-L2-MISSIONLONG.fits',
+            observation_time_start=datetime(1996, 1, 23, 0, 0),
+            observation_time_end=datetime(2021, 5, 15, 23, 59),
+            instrument='VIRGO', size=32652.0),
+        DatabaseEntry(
+            source='SOHO', provider='SDAC', physobs='intensity',
+            fileid='/archive/soho/private/data/processed/virgo/spm/VIRGO-SPM-RED-L2-MISSIONLONG.fits',
+            observation_time_start=datetime(1996, 1, 23, 0, 0),
+            observation_time_end=datetime(2021, 5, 15, 23, 59),
+            instrument='VIRGO', size=32652.0),
+        DatabaseEntry(
+            source='SOHO', provider='SDAC', physobs='intensity',
+            fileid='/archive/soho/private/data/processed/virgo/loi/VIRGO-LOI-ALL-PIXELS-LEVEL2-19960401-20210430_V01.fits',
+            observation_time_start=datetime(1996, 4, 1, 0, 0),
+            observation_time_end=datetime(2021, 4, 30, 23, 59),
+            instrument='VIRGO', size=1677722.0),
+        DatabaseEntry(
+            source='SOHO', provider='SDAC', physobs='intensity',
+            fileid='/archive/soho/private/data/processed/virgo/sph/VIRGO_D4.2_SPH_960411_120914.tar.gz',
+            observation_time_start=datetime(1996, 4, 11, 0, 0),
+            observation_time_end=datetime(2012, 9, 14, 0, 0),
+            instrument='VIRGO', size=512000.0),
         DatabaseEntry(
             source='SOHO', provider='SDAC', physobs='intensity',
             fileid='/archive/soho/private/data/processed/virgo/level1/1212/HK/121222_1.H01',
             observation_time_start=datetime(2012, 12, 23, 23, 59, 3),
             observation_time_end=datetime(2012, 12, 24, 23, 59, 2),
-            instrument='VIRGO', size=155.0, wavemin=None,
-            wavemax=None),
+            instrument='VIRGO', size=155.0),
         DatabaseEntry(
             source='SOHO', provider='SDAC', physobs='intensity',
             fileid='/archive/soho/private/data/processed/virgo/level1/1212/LOI/121224_1.L01',
-            observation_time_end=datetime(2012, 12, 24, 23, 59, 2),
             observation_time_start=datetime(2012, 12, 23, 23, 59, 3),
-            instrument='VIRGO', size=329.0, wavemin=None,
-            wavemax=None),
+            observation_time_end=datetime(2012, 12, 24, 23, 59, 2),
+            instrument='VIRGO', size=329.0),
         DatabaseEntry(
             source='SOHO', provider='SDAC', physobs='intensity',
             fileid='/archive/soho/private/data/processed/virgo/level1/1212/SPM/121222_1.S02',
             observation_time_start=datetime(2012, 12, 23, 23, 59, 3),
             observation_time_end=datetime(2012, 12, 24, 23, 59, 2),
-            instrument='VIRGO', size=87.0, wavemin=None,
-            wavemax=None),
+            instrument='VIRGO', size=87.0),
         DatabaseEntry(
             source='SOHO', provider='SDAC', physobs='intensity',
             fileid='/archive/soho/private/data/processed/virgo/level1/1212/DIARAD/121222_1.D01',
             observation_time_start=datetime(2012, 12, 24, 0, 1, 58),
             observation_time_end=datetime(2012, 12, 25, 0, 1, 57),
-            instrument='VIRGO', size=14.0, wavemin=None,
-            wavemax=None),
-        DatabaseEntry(
-            source='SOHO', provider='SDAC', physobs='intensity',
-            fileid='/archive/soho/private/data/processed/virgo/sph/VIRGO_D4.2_SPH_960411_120914.tar.gz',
-            observation_time_start=datetime(1996, 4, 11, 0, 0),
-            observation_time_end=datetime(2012, 9, 14, 0, 0),
-            instrument='VIRGO', size=512000.0, wavemin=None,
-            wavemax=None),
-        DatabaseEntry(
-            source='SOHO', provider='SDAC', physobs='intensity',
-            fileid='/archive/soho/private/data/processed/virgo/spm/SPM_blue_intensity_series.tar.gz',
-            observation_time_start=datetime(1996, 4, 11, 0, 0),
-            observation_time_end=datetime(2014, 3, 30, 23, 59),
-            instrument='VIRGO', size=32652.0, wavemin=None,
-            wavemax=None),
-        DatabaseEntry(
-            source='SOHO', provider='SDAC', physobs='intensity',
-            fileid='/archive/soho/private/data/processed/virgo/spm/SPM_green_intensity_series.tar.gz',
-            observation_time_start=datetime(1996, 4, 11, 0, 0),
-            observation_time_end=datetime(2014, 3, 30, 23, 59),
-            instrument='VIRGO', size=32652.0, wavemin=None,
-            wavemax=None),
-        DatabaseEntry(
-            source='SOHO', provider='SDAC', physobs='intensity',
-            fileid='/archive/soho/private/data/processed/virgo/spm/SPM_red_intensity_series.tar.gz',
-            observation_time_start=datetime(1996, 4, 11, 0, 0),
-            observation_time_end=datetime(2014, 3, 30, 23, 59),
-            instrument='VIRGO', size=32652.0, wavemin=None,
-            wavemax=None),
-        DatabaseEntry(
-            source='SOHO', provider='SDAC', physobs='intensity',
-            fileid='/archive/soho/private/data/processed/virgo/level1/1212/DIARAD/121222_1.D01',
-            observation_time_start=datetime(2012, 12, 24, 0, 1, 58),
-            observation_time_end=datetime(2012, 12, 25, 0, 1, 57),
-            instrument='VIRGO', size=14.0, wavemin=None,
-            wavemax=None),
-        DatabaseEntry(
-            source='SOHO', provider='SDAC', physobs='intensity',
-            fileid='/archive/soho/private/data/processed/virgo/tsi_full/VIRGO_TSI_hourly.dat.tar.gz',
-            observation_time_start=datetime(1995, 12, 2, 0, 0),
-            observation_time_end=datetime(2020, 1, 1, 0, 0),
-            instrument='VIRGO', size=3072.0, wavemin=None,
-            wavemax=None),
-        DatabaseEntry(
-            source='SOHO', provider='SDAC', physobs='intensity',
-            fileid='/archive/soho/private/data/processed/virgo/tsi_full/VIRGO_TSI_daily.dat.tar.gz',
-            observation_time_start=datetime(1995, 12, 2, 0, 0),
-            observation_time_end=datetime(2020, 1, 1, 0, 0),
-            instrument='VIRGO', size=140.0, wavemin=None,
-            wavemax=None),
-        DatabaseEntry(
-            source='SOHO', provider='SDAC', physobs='intensity',
-            fileid='/archive/soho/private/data/processed/virgo/spm/VIRGO-SPM-BLUE-L2-MISSIONLONG.fits',
-            observation_time_start=datetime(1996, 1, 23, 0, 0),
-            observation_time_end=datetime(2019, 9, 30, 23, 59),
-            instrument='VIRGO', size=32652.0, wavemin=None,
-            wavemax=None),
-        DatabaseEntry(
-            source='SOHO', provider='SDAC', physobs='intensity',
-            fileid='/archive/soho/private/data/processed/virgo/spm/VIRGO-SPM-GREEN-L2-MISSIONLONG.fits',
-            observation_time_start=datetime(1996, 1, 23, 0, 0),
-            observation_time_end=datetime(2019, 9, 30, 23, 59),
-            instrument='VIRGO', size=32652.0, wavemin=None,
-            wavemax=None),
-        DatabaseEntry(
-            source='SOHO', provider='SDAC', physobs='intensity',
-            fileid='/archive/soho/private/data/processed/virgo/spm/VIRGO-SPM-RED-L2-MISSIONLONG.fits',
-            observation_time_start=datetime(1996, 1, 23, 0, 0),
-            observation_time_end=datetime(2019, 9, 30, 23, 59),
-            instrument='VIRGO', size=32652.0, wavemin=None,
-            wavemax=None),
-        DatabaseEntry(
-            source='SOHO', provider='SDAC', physobs='intensity',
-            fileid='/archive/soho/private/data/processed/virgo/sph/VIRGO_D4.2_SPH_960411_120914.tar.gz',
-            observation_time_start=datetime(1996, 4, 11, 0, 0),
-            observation_time_end=datetime(2012, 9, 14, 0, 0),
-            instrument='VIRGO', size=512000.0, wavemin=None,
-            wavemax=None)
-    ]
+            instrument='VIRGO', size=14.0)]
 
     for e in entries:
         assert e in expected
+    for e in expected:
+        assert e in entries
 
 
 def test_create_display_table_missing_entries():
