@@ -3,3 +3,8 @@
 This packages contains python packages that are bundled with SunPy but are
 external to SunPy, and hence are developed in a separate source tree.
 """
+
+from .appdirs import *  # NOQA
+from .distro import *  # NOQA
+from .inflect import *  # NOQA
+from .parse import *  # NOQA
