@@ -4,7 +4,7 @@ Functions for geometrical image transformation and warping.
 import numbers
 
 import numpy as np
-import scipy.ndimage.interpolation
+import scipy.ndimage
 
 from sunpy.util.exceptions import warn_user
 
@@ -103,7 +103,7 @@ def affine_transform(image, rmatrix, order=3, scale=1.0, image_center=None,
         if np.any(np.isnan(image)):
             warn_user("Setting NaNs to 0 for SciPy rotation.")
         # Transform the image using the scipy affine transform
-        rotated_image = scipy.ndimage.interpolation.affine_transform(
+        rotated_image = scipy.ndimage.affine_transform(
             np.nan_to_num(image).T, rmatrix, offset=shift, order=order,
             mode='constant', cval=missing).T
     else:
