@@ -1,4 +1,5 @@
 import os
+import sys
 
 import numpy as np
 import pytest
@@ -16,6 +17,10 @@ sunpy_frames = list(map(lambda name: getattr(frames, name), frames.__all__))
 # Don't test the two base frames
 sunpy_frames = [frame for frame in sunpy_frames if 'base' not in frame.name]
 
+# TODO: Delete after a major pytest release
+if sys.version_info > (3, 9):
+    pytest.skip("pytest + asdf do not play well", allow_module_level=True)
+
 
 @pytest.fixture(params=sunpy_frames)
 @asdf_entry_points
