@@ -2,6 +2,7 @@ import os
 from pathlib import Path
 from collections import OrderedDict
 
+import numpy as np
 import pytest
 
 import astropy.io.fits as fits
@@ -11,7 +12,7 @@ import sunpy.data.test
 import sunpy.io.fits
 from sunpy.data.test.waveunit import MEDN_IMAGE, MQ_IMAGE, NA_IMAGE, SVSM_IMAGE
 from sunpy.io.fits import extract_waveunit, get_header, header_to_fits
-from sunpy.util import MetaDict, SunpyUserWarning
+from sunpy.util import MetaDict, SunpyMetadataWarning
 
 testpath = sunpy.data.test.rootdir
 
@@ -83,12 +84,54 @@ def test_simple_write_compressed(tmpdir):
         assert isinstance(hdul[1], fits.CompImageHDU)
 
 
+def test_simple_write_compressed_difftypeinst(tmpdir):
+    # `hdu_type=fits.CompImageHDU` and `hdu_type=fits.CompImageHDU()`
+    # should produce identical FITS files
+    data, header = sunpy.io.fits.read(AIA_171_IMAGE)[0]
+    outfile_type = str(tmpdir / "test_type.fits")
+    outfile_inst = str(tmpdir / "test_inst.fits")
+    sunpy.io.fits.write(outfile_type, data, header, hdu_type=fits.CompImageHDU)
+    sunpy.io.fits.write(outfile_inst, data, header, hdu_type=fits.CompImageHDU())
+    assert fits.FITSDiff(outfile_type, outfile_inst, ignore_comments=['PCOUNT']).identical
+
+
+@pytest.mark.parametrize(
+    'kwargs, should_fail',
+    [({}, False),
+     ({'quantize_level': -32}, True)]
+)
+def test_simple_write_compressed_instance(tmpdir, kwargs, should_fail):
+    data, header = sunpy.io.fits.read(AIA_171_IMAGE)[0]
+    outfile = tmpdir / "test.fits"
+
+    # Ensure HDU instance is used correctly
+    hdu = fits.CompImageHDU(data=np.array([0.]), **kwargs)
+    hdu.header['HELLO'] = 'world'  # should be in the written file
+    hdu.header['TELESCOP'] = 'other'  # should be replaced with 'SDO/AIA'
+    hdu.header['NAXIS'] = 5  # should be replaced with 2
+    sunpy.io.fits.write(str(outfile), data, header, hdu_type=hdu)
+    assert outfile.exists()
+    with fits.open(str(outfile)) as hdul:
+        assert len(hdul) == 2
+        assert isinstance(hdul[1], fits.CompImageHDU)
+        assert hdul[1].header['HELLO'] == 'world'
+        assert hdul[1].header['TELESCOP'] == 'SDO/AIA'
+        assert hdul[1].header['NAXIS'] == 2
+        data_preserved = hdul[1].data == pytest.approx(data, abs=10)
+        print(np.abs(hdul[1].data - data).max())
+        print(kwargs)
+        if should_fail:  # high compression setting preserved
+            assert not data_preserved
+        else:
+            assert data_preserved
+
+
 def test_write_with_metadict_header_astropy(tmpdir):
     with fits.open(AIA_171_IMAGE) as fits_file:
         data, header = fits_file[0].data, fits_file[0].header
     meta_header = MetaDict(OrderedDict(header))
     temp_file = tmpdir / "temp.fits"
-    with pytest.warns(SunpyUserWarning, match='The meta key comment is not valid ascii'):
+    with pytest.warns(SunpyMetadataWarning, match='The meta key comment is not valid ascii'):
         sunpy.io.fits.write(str(temp_file), data, meta_header)
     assert temp_file.exists()
     fits_file.close()
@@ -112,7 +155,7 @@ def test_fitsheader():
 
 def test_warn_nonascii():
     # Check that a non-ascii character raises a warning and not an error
-    with pytest.warns(SunpyUserWarning, match='not valid ascii'):
+    with pytest.warns(SunpyMetadataWarning, match='not valid ascii'):
         fits = header_to_fits({'bad': 'test\t',
                                'good': 'test'})
     assert 'GOOD' in fits.keys()
@@ -121,7 +164,7 @@ def test_warn_nonascii():
 
 def test_warn_nan():
     # Check that a NaN value raises a warning and not an error
-    with pytest.warns(SunpyUserWarning, match='has a NaN value'):
+    with pytest.warns(SunpyMetadataWarning, match='has a NaN value'):
         fits = header_to_fits({'bad': float('nan'),
                                'good': 1.0})
     assert 'GOOD' in fits.keys()
@@ -130,7 +173,7 @@ def test_warn_nan():
 
 def test_warn_longkey():
     # Check that a key that is too long raises a warning and not an error
-    with pytest.warns(SunpyUserWarning, match='The meta key badlongkey is too long'):
+    with pytest.warns(SunpyMetadataWarning, match='The meta key badlongkey is too long'):
         fits = header_to_fits({'badlongkey': 'test',
                                'goodkey': 'test'})
     assert 'GOODKEY' in fits.keys()
