@@ -16,7 +16,6 @@ def meta_keywords():
 
     Examples
     --------
-
     Returns a dictionary of all meta keywords that are used in a `sunpy.map.GenericMap` header:
         >>> import sunpy.map
         >>> sunpy.map.meta_keywords()
@@ -51,7 +50,7 @@ def make_fitswcs_header(data, coordinate,
         data array (in numpy order, i.e. ``(y_size, x_size)``).
     coordinate : `~astropy.coordinates.SkyCoord` or `~astropy.coordinates.BaseCoordinateFrame`
         The coordinate of the reference pixel.
-    reference_pixel :`~astropy.units.Quantity` of size 2, optional
+    reference_pixel : `~astropy.units.Quantity`, optional
         Reference pixel along each axis. These are expected to be Cartestian ordered, i.e
         the first index is the x axis, second index is the y axis. Defaults to
         the center of data array, ``(data.shape[1] - 1)/2., (data.shape[0] - 1)/2.)``,
@@ -64,7 +63,7 @@ def make_fitswcs_header(data, coordinate,
     rotation_angle : `~astropy.units.Quantity`, optional
         Coordinate system rotation angle, will be converted to a rotation
         matrix and stored in the ``PCi_j`` matrix. Can not be specified with
-        ``rotation_matrix``.
+        ``rotation_matrix``. Defaults to no rotation.
     rotation_matrix : `~numpy.ndarray` of dimensions 2x2, optional
         Matrix describing the rotation required to align solar North with
         the top of the image in FITS ``PCi_j`` convention. Can not be specified
@@ -150,6 +149,8 @@ def _validate_coordinate(coordinate):
 def _set_rotation_params(meta_wcs, rotation_angle, rotation_matrix):
     if rotation_angle is not None and rotation_matrix is not None:
         raise ValueError("Can not specify both rotation angle and rotation matrix.")
+    if rotation_angle is None and rotation_matrix is None:
+        rotation_angle = 0 * u.deg
 
     if rotation_angle is not None:
         lam = meta_wcs['cdelt1'] / meta_wcs['cdelt2']
@@ -235,7 +236,7 @@ def get_observer_meta(observer, rsun: (u.Mm, None)):
 
     Parameters
     ----------
-    coordinate : `~astropy.coordinates.BaseCoordinateFrame`
+    observer : `~astropy.coordinates.BaseCoordinateFrame`
         The coordinate of the observer, must be transformable to Heliographic
         Stonyhurst.
     rsun : `astropy.units.Quantity`
