@@ -1,18 +1,11 @@
 """Hinode XRT and SOT Map subclass definitions"""
+from sunpy.map import GenericMap
 
 __author__ = ["Jack Ireland, Jose Ivan Campos-Rozo, David Perez-Suarez"]
 __email__ = "jack.ireland@nasa.gov"
 
-from sunpy import log
-from sunpy.map import GenericMap
-
 __all__ = ['XRTMap', 'SOTMap']
 
-# the following values comes from xrt_prep.pro
-# search for saturation in
-# http://darts.jaxa.jp/pub/ssw/hinode/xrt/idl/util/xrt_prep.pro
-# SATURATION_LIMIT = 2500
-
 
 def _lower_list(l):
     return [item.lower() for item in l]
@@ -43,31 +36,33 @@ class XRTMap(GenericMap):
                                   "Be_thick", "Gband", "Ti_poly"]
 
     def __init__(self, data, header, **kwargs):
-
         super().__init__(data, header, **kwargs)
 
-        if self.meta.get('timesys', '') == 'UTC (TBR)':
-            log.debug('Modifying TIMESYS keyword from "UTC (TBR)" to "UTC"')
-            self.meta['timesys'] = 'UTC'
-
-        # converting data array to masked array
-        # self.data = ma.masked_where(self.data > SATURATION_LIMIT, self.data)
-
         fw1 = header.get('EC_FW1_')
         if fw1.lower() not in _lower_list(self.filter_wheel1_measurements):
             raise ValueError('Unpexpected filter wheel 1 in header.')
-        fw1 = fw1.replace("_", " ")
 
         fw2 = header.get('EC_FW2_')
         if fw2.lower() not in _lower_list(self.filter_wheel2_measurements):
             raise ValueError('Unpexpected filter wheel 2 in header.')
-        fw2 = fw2.replace("_", " ")
 
-        self.meta['detector'] = "XRT"
-#        self.meta['instrume'] = "XRT"
-        self.meta['telescop'] = "Hinode"
         self.plot_settings['cmap'] = 'hinodexrt'
 
+    @property
+    def _timesys(self):
+        if self.meta.get('timesys', '').upper() == 'UTC (TBR)':
+            return 'UTC'
+        else:
+            return super()._timesys
+
+    @property
+    def detector(self):
+        return "XRT"
+
+    @property
+    def observatory(self):
+        return "Hinode"
+
     @property
     def measurement(self):
         fw1 = self.meta.get('EC_FW1_').replace("_", " ")
@@ -116,9 +111,6 @@ class SOTMap(GenericMap):
 
     def __init__(self, data, header, **kwargs):
         super().__init__(data, header, **kwargs)
-
-        self.meta['detector'] = "SOT"
-        self.meta['telescop'] = "Hinode"
         self._nickname = self.detector
 
         # TODO (add other options, Now all threated as intensity. This follows
@@ -134,6 +126,14 @@ class SOTMap(GenericMap):
 
         self.plot_settings['cmap'] = 'hinodesot' + color[self.instrument]
 
+    @property
+    def detector(self):
+        return "XRT"
+
+    @property
+    def observatory(self):
+        return "Hinode"
+
     @classmethod
     def is_datasource_for(cls, data, header, **kwargs):
         """Determines if header corresponds to an SOT image."""
