@@ -1,4 +1,5 @@
 import astropy.units as u
+from astropy.coordinates import SkyCoord
 from astropy.visualization import PowerStretch
 from astropy.visualization.mpl_normalize import ImageNormalize
 
@@ -29,17 +30,8 @@ class KCorMap(GenericMap):
     """
 
     def __init__(self, data, header, **kwargs):
-
         super().__init__(data, header, **kwargs)
 
-        # Fill in some missing info
-        self.meta['observatory'] = 'MLSO'
-        self.meta['detector'] = 'KCor'
-        self.meta['waveunit'] = self.meta.get('waveunit', 'nm')
-        # Since KCor is on Earth, no need to raise the warning in mapbase
-        self.meta['dsun_obs'] = self.meta.get('dsun_obs',
-                                              sun.earth_distance(self.date).to(u.m).value)
-        self.meta['hgln_obs'] = self.meta.get('hgln_obs', 0.0)
         self._nickname = self.detector
 
         self.plot_settings['cmap'] = self._get_cmap_name()
@@ -56,10 +48,28 @@ class KCorMap(GenericMap):
 
     @property
     def observatory(self):
+        return "MLSO"
+
+    @property
+    def detector(self):
+        return "KCor"
+
+    @property
+    def waveunit(self):
         """
-        Returns the observatory.
+        If the WAVEUNIT FITS keyword is not present, defaults to nanometers.
         """
-        return self.meta['observatory']
+        unit = self.meta.get("waveunit", "nm")
+        return u.Unit(unit)
+
+    @property
+    def _default_observer_coordinate(self):
+        # Override missing metadata in the observer coordinate
+        dsun_obs = self.meta.get('dsun_obs', sun.earth_distance(self.date).to_value(u.m))
+        return SkyCoord(self.meta.get('hgln_obs', 0.0) * u.deg,
+                        self.meta.get('hglt_obs', 0.0) * u.deg,
+                        self.meta.get('dsun_obs', dsun_obs) * u.m,
+                        frame="heliographic_stonyhurst")
 
     @classmethod
     def is_datasource_for(cls, data, header, **kwargs):
