@@ -5,16 +5,14 @@ This particular test file pertains to EITMap.
 
 import os
 import glob
-import numpy as np
-from matplotlib import colors
 
 import pytest
 
 import astropy.units as u
 
-from sunpy.map.sources.soho import EITMap
-from sunpy.map import Map
 import sunpy.data.test
+from sunpy.map import Map
+from sunpy.map.sources.soho import EITMap
 
 path = sunpy.data.test.rootdir
 fitslist = glob.glob(os.path.join(path, "EIT", "*"))
@@ -52,3 +50,13 @@ def test_measurement(createEIT):
 def test_rsun(createEIT):
     """Tests the measurement property of the EITMap object."""
     assert u.allclose(createEIT.rsun_obs, 979.0701*u.arcsec)
+
+
+def test_norm_clip(createEIT):
+    # Tests that the default normalizer has clipping disabled
+    assert not createEIT.plot_settings['norm'].clip
+
+
+def test_wcs(createEIT):
+    # Smoke test that WCS is valid and can transform from pixels to world coordinates
+    createEIT.pixel_to_world(0*u.pix, 0*u.pix)
