@@ -5,6 +5,8 @@ This particular test file pertains to HIMap.
 import os
 import glob
 
+import astropy.units as u
+
 import sunpy.data.test
 from sunpy.map import Map
 from sunpy.map.sources.stereo import HIMap
@@ -39,3 +41,8 @@ def test_observatory():
 def test_norm_clip():
     # Tests that the default normalizer has clipping disabled
     assert not hi.plot_settings['norm'].clip
+
+
+def test_wcs():
+    # Smoke test that WCS is valid and can transform from pixels to world coordinates
+    hi.pixel_to_world(0*u.pix, 0*u.pix)
