@@ -7,6 +7,8 @@ import glob
 
 import pytest
 
+import astropy.units as u
+
 import sunpy.data.test
 from sunpy.map import Map
 from sunpy.map.sources.suvi import SUVIMap
@@ -47,3 +49,12 @@ def test_detector(suvi):
 def test_norm_clip(suvi):
     # Tests that the default normalizer has clipping disabled
     assert not suvi.plot_settings['norm'].clip
+
+
+# SUVI provides observer coordinate information in an OBSGEO system, so this test
+# needs remote data to access the latest IERS table to do a coordiante transformation from
+# OBSGEO to heliographic Stonyhurst coordiantes.
+@pytest.mark.remote_data
+def test_wcs(suvi):
+    # Smoke test that WCS is valid and can transform from pixels to world coordinates
+    suvi.pixel_to_world(0*u.pix, 0*u.pix)
