@@ -103,8 +103,7 @@ def generic_map():
     return sunpy.map.Map((data, header))
 
 
-@pytest.fixture
-def simple_map():
+def make_simple_map():
     # A 3x3 map, with it's center at (0, 0), and scaled differently in
     # each direction
     data = np.arange(9).reshape((3, 3))
@@ -117,6 +116,9 @@ def simple_map():
     return sunpy.map.Map(data, header)
 
 
+simple_map = pytest.fixture(make_simple_map)
+
+
 @pytest.fixture
 def carrington_map():
     # This is a 20 x 20 map in a Carrington frame, with the reference pixel *not* at the
