@@ -19,7 +19,7 @@ import sunpy.data.test
 import sunpy.map
 from sunpy.coordinates import HeliographicStonyhurst
 from sunpy.tests.helpers import figure_test, fix_map_wcs
-from sunpy.util.exceptions import SunpyDeprecationWarning, SunpyUserWarning
+from sunpy.util.exceptions import SunpyUserWarning
 
 testpath = sunpy.data.test.rootdir
 pytestmark = pytest.mark.filterwarnings('ignore:Missing metadata')
@@ -103,13 +103,6 @@ def test_peek_grid_limb_aia171(aia171_test_map):
     aia171_test_map.peek(draw_grid=True, draw_limb=True)
 
 
-@figure_test
-def test_plot_aia171_nowcsaxes(aia171_test_map):
-    ax = plt.gca()
-    with pytest.warns(SunpyDeprecationWarning, match='WCSAxes not being used as the axes'):
-        aia171_test_map.plot(axes=ax)
-
-
 @figure_test
 def test_rectangle_aia171_width_height(aia171_test_map):
     aia171_test_map.plot()
@@ -141,6 +134,13 @@ def test_quadrangle_aia17_width_height(aia171_test_map):
     aia171_test_map.draw_quadrangle(bottom_left=bottom_left, width=w, height=h)
 
 
+@figure_test
+def test_quadrangle_aia17_pix_width_height(aia171_test_map):
+    aia171_test_map.plot()
+    aia171_test_map.draw_quadrangle(bottom_left=(50, 50)*u.pix, width=30*u.pix,
+                                    height=50*u.pix, edgecolor="cyan")
+
+
 @figure_test
 def test_quadrangle_aia17_top_right(aia171_test_map):
     aia171_test_map.plot()
@@ -153,15 +153,31 @@ def test_quadrangle_aia17_top_right(aia171_test_map):
 
 
 @figure_test
-def test_plot_masked_aia171(aia171_test_map_with_mask):
-    aia171_test_map_with_mask.plot()
+def test_quadrangle_aia17_pix_top_right(aia171_test_map):
+    aia171_test_map.plot()
+    aia171_test_map.draw_quadrangle(bottom_left=(50, 50)*u.pix,
+                                    top_right=(80, 90)*u.pix, edgecolor='cyan')
 
 
 @figure_test
-def test_plot_masked_aia171_nowcsaxes(aia171_test_map_with_mask):
-    ax = plt.gca()
-    with pytest.warns(SunpyDeprecationWarning, match='WCSAxes not being used as the axes'):
-        aia171_test_map_with_mask.plot(axes=ax)
+def test_quadrangle_aia17_pix_top_right_different_axes(aia171_test_map):
+    # Plot the map rotated by 30 degrees
+    aia171_test_map.rotate(30*u.deg).plot()
+    # Plot a rectangle in the pixel space of the original map
+    aia171_test_map.draw_quadrangle(bottom_left=(50, 50)*u.pix,
+                                    top_right=(80, 90)*u.pix, edgecolor='cyan')
+
+
+@figure_test
+def test_quadrangle_aia17_pix_top_right_different_axes(aia171_test_map):
+    aia171_test_map.rotate(30*u.deg).plot()
+    aia171_test_map.draw_quadrangle(bottom_left=(50, 50)*u.pix,
+                                    top_right=(80, 90)*u.pix, edgecolor='cyan')
+
+
+@figure_test
+def test_plot_masked_aia171(aia171_test_map_with_mask):
+    aia171_test_map_with_mask.plot()
 
 
 @figure_test
@@ -203,28 +219,12 @@ def test_plot_superpixel(carrington_map):
         ax.coords.grid(True, color='tab:red', ls='solid', lw=2, alpha=1)
 
 
-@figure_test
-def test_plot_aia171_superpixel_nowcsaxes(aia171_test_map):
-    ax = plt.gca()
-    with pytest.warns(SunpyDeprecationWarning, match='WCSAxes not being used as the axes'):
-        aia171_test_map.superpixel(
-            (9, 7) * u.pix, offset=(4, 4) * u.pix).plot(axes=ax)
-
-
 @figure_test
 def test_plot_masked_aia171_superpixel(aia171_test_map_with_mask):
     aia171_test_map_with_mask.superpixel(
         (9, 7) * u.pix, offset=(4, 4) * u.pix).plot()
 
 
-@figure_test
-def test_plot_masked_aia171_superpixel_nowcsaxes(aia171_test_map_with_mask):
-    ax = plt.gca()
-    with pytest.warns(SunpyDeprecationWarning, match='WCSAxes not being used as the axes'):
-        aia171_test_map_with_mask.superpixel(
-            (9, 7) * u.pix, offset=(4, 4) * u.pix).plot(axes=ax)
-
-
 @figure_test
 def test_draw_contours_aia(aia171_test_map):
     aia171_test_map.plot()
