@@ -28,16 +28,16 @@ def get_observatory_groups():
     >>>
     >>> groups = get_observatory_groups() #doctest: +REMOTE_DATA
     >>> groups['Group'] #doctest: +REMOTE_DATA
-        <Column name='Group' dtype='str55' length=72>
+        <Column name='Group' dtype='str55' length=...>
                         ACE
                       AMPTE
         ...
                     Voyager
                        Wind
     >>> groups.loc['STEREO'] #doctest: +REMOTE_DATA
-    <Row index=58>
+    <Row index=...>
     Group                                  Observatories
-    str55                                      str531
+    str55                                      str...
     ------ -----------------------------------------------------------------------------
     STEREO 'Ahead', 'Behind', 'STA', 'STB', 'STEREO', 'STEREOA', 'STEREOB', 'sta', 'stb'
     """
