@@ -25,6 +25,8 @@ class EVEClient(GenericClient):
     Results from 1 Provider:
     <BLANKLINE>
     2 Results from the EVEClient:
+    Source: https://lasp.colorado.edu/eve/data_access/evewebdata/quicklook/L0CS/SpWx/
+    <BLANKLINE>
            Start Time               End Time        Instrument ... Provider Level
     ----------------------- ----------------------- ---------- ... -------- -----
     2016-01-01 00:00:00.000 2016-01-01 23:59:59.999        EVE ...     LASP     0
@@ -37,6 +39,10 @@ class EVEClient(GenericClient):
                r'L0CS/SpWx/%Y/%Y%m%d_EVE_L0CS_DIODES_1m.txt')
     pattern = '{}/SpWx/{:4d}/{year:4d}{month:2d}{day:2d}_EVE_L{Level:1d}{}'
 
+    @property
+    def info_url(self):
+        return 'https://lasp.colorado.edu/eve/data_access/evewebdata/quicklook/L0CS/SpWx/'
+
     @classmethod
     def register_values(cls):
         from sunpy.net import attrs
