@@ -43,7 +43,7 @@ class UnifiedResponse(Sequence):
         """
         Parameters
         ----------
-        results : `sunpy.net.base_client.QueryResponseTable`
+        *results : `sunpy.net.base_client.QueryResponseTable`
             One or more QueryResponse objects.
         """
         self._list = []
@@ -285,7 +285,7 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
 
         Parameters
         ----------
-        query : `sunpy.net.vso.attrs`, `sunpy.net.jsoc.attrs`
+        *query : `sunpy.net.vso.attrs`, `sunpy.net.jsoc.attrs`
             A query consisting of multiple parameters which define the
             requested data.  The query is specified using attributes from the
             VSO and the JSOC.  The query can mix attributes from the VSO and
@@ -326,7 +326,7 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
 
         Parameters
         ----------
-        query_results : `sunpy.net.fido_factory.UnifiedResponse` or `~sunpy.net.base_client.QueryResponseTable`
+        *query_results : `sunpy.net.fido_factory.UnifiedResponse` or `~sunpy.net.base_client.QueryResponseTable`
             Container returned by query method, or multiple.
         path : `str`
             The directory to retrieve the files into. Can refer to any fields
@@ -380,10 +380,23 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
         if "wait" in kwargs:
             raise ValueError("wait is not a valid keyword argument to Fido.fetch.")
 
+        # TODO: Remove when parfive allows us to special case URLS.
+        # Avoid more than one connection for JSOC only requests.
+        from sunpy.net.jsoc import JSOCClient
+
+        is_jsoc_only = False
+        for query_result in query_results:
+            if isinstance(query_result, UnifiedResponse):
+                is_jsoc_only = all([isinstance(result.client, JSOCClient) for result in query_result])
+            elif isinstance(query_result, QueryResponseTable):
+                is_jsoc_only = all([isinstance(result.table.client, JSOCClient) for result in query_result])
         if downloader is None:
+            if is_jsoc_only:
+                max_conn = 1
+                kwargs['max_splits'] = 1
             downloader = Downloader(max_conn=max_conn, progress=progress, overwrite=overwrite)
         elif not isinstance(downloader, parfive.Downloader):
-            raise TypeError("The downloader argument must be a parfive.Downloader object.")
+            raise TypeError("The downloader argument must be a parfive.Downloader instance.")
 
         # Handle retrying failed downloads
         retries = [isinstance(arg, Results) for arg in query_results]
@@ -395,8 +408,7 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
                 results._errors += dr._errors
             return results
         elif any(retries):
-            raise TypeError("If any arguments to fetch are "
-                            "`parfive.Results` objects, all arguments must be.")
+            raise TypeError("If any arguments to fetch are `parfive.Results` objects, all arguments must be.")
 
         reslist = []
         for query_result in query_results:
@@ -452,7 +464,7 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
 
         Parameters
         ----------
-        query : collection of `~sunpy.net.vso.attr` objects
+        *query : collection of `~sunpy.net.vso.attr` objects
 
         Returns
         -------
