@@ -16,7 +16,7 @@ from sunpy.net.base_client import BaseClient, QueryResponseTable
 from sunpy.net.helio import attrs as ha
 from sunpy.net.helio import parser
 from sunpy.time import parse_time
-from sunpy.util.exceptions import warn_deprecated
+from sunpy.util.exceptions import warn_deprecated, warn_user
 
 __all__ = ['HECClient', 'HECResponse']
 
@@ -106,6 +106,10 @@ class HECClient(BaseClient):
         Used to utilize the service's TimeQuery() method, this is a simple
         interface between the sunpy module library and the web-service's API.
 
+        .. note::
+           By default the maximum records returned by the service are limited to 500.
+           To obtain more results ``a.helio.MaxRecords`` must be set to a higher value.
+
         Examples
         --------
         >>> from sunpy.net.helio import attrs as ha
@@ -152,7 +156,7 @@ class HECClient(BaseClient):
             table = str.encode(table)
         start_time = qrdict['Time'].start
         end_time = qrdict['Time'].end
-        max_records = qrdict.get('max_records', 10)
+        max_records = qrdict.get('max_records', 500)
         while table is None:
             table = self.select_table()
         start_time = parse_time(start_time)
@@ -162,7 +166,12 @@ class HECClient(BaseClient):
                                                     FROM=table,
                                                     MAXRECORDS=max_records)
         results = votable_handler(etree.tostring(results))
-        return HECResponse(results.to_table(), client=self)
+        table = HECResponse(results.to_table(), client=self)
+        if len(table) == max_records == 500:
+            warn_user("Number of results is the same as the default `max_records` of 500. "
+                      "It is possible your query has been truncated. "
+                      "If you want to change this, set `a.helio.MaxRecords` to a higher value.")
+        return table
 
     def get_table_names(self):
         """
