@@ -12,7 +12,6 @@ from sunpy.net.helio.parser import (
     webservice_parser,
     wsdl_retriever,
 )
-from sunpy.util.exceptions import SunpyDeprecationWarning
 
 # Currently helio makes unverified requests - this filter should be removed when
 # https://github.com/sunpy/sunpy/issues/4401 is fixed
@@ -276,16 +275,6 @@ def test_select_table(client, monkeypatch):
     assert client.select_table() is None
 
 
-@pytest.mark.remote_data
-def test_time_query(client):
-    start = '2005/01/03'
-    end = '2005/12/03'
-    table_name = 'rhessi_hxr_flare'
-    with pytest.raises(SunpyDeprecationWarning):
-        res = client.time_query(start, end, table=table_name, max_records=10)
-        assert len(res.array) == 10
-
-
 @pytest.mark.remote_data
 def test_client_search(client):
     start = '2005/01/03'
