@@ -1,27 +1,25 @@
-# -*- coding: utf-8 -*-
 import pytest
 
 import astropy.units as u
 
 import sunpy.net.jsoc as jsoc
 import sunpy.net.jsoc.attrs as attrs
-import sunpy.net.vso.attrs as vso_attrs
-
-from sunpy.net.attr import AttrOr, AttrAnd
+from sunpy.net import _attrs as core_attrs
+from sunpy.net.attr import AttrAnd, AttrOr
 
 
 @pytest.mark.parametrize(("attr1, attr2"),
                          [(attrs.Series('foo'), attrs.Series('boo')),
-                         (attrs.Protocol('a1'), attrs.Protocol('a2')),
-                         (attrs.Notify('email@somemail.com'),
-                          attrs.Notify('someemail@somemail.com'))])
+                          (attrs.Protocol('a1'), attrs.Protocol('a2')),
+                          (attrs.Notify('email@somemail.com'),
+                           attrs.Notify('someemail@somemail.com'))])
 def test_and(attr1, attr2):
     pytest.raises(TypeError, lambda: attr1 & attr2)
 
 
 def test_basicquery():
     a1 = attrs.Series('foo')
-    t1 = vso_attrs.Time('2012/01/01', '2013/1/2')
+    t1 = core_attrs.Time('2012/01/01', '2013/1/2')
     ans1 = jsoc.jsoc.and_(a1, t1)
     assert isinstance(ans1, AttrAnd)
     assert len(ans1.attrs) == 2
@@ -30,7 +28,7 @@ def test_basicquery():
 def test_mediumquery():
     a1 = attrs.Series('foo1')
     a2 = attrs.Series('foo2')
-    t1 = vso_attrs.Time('2012/01/01', '2013/1/2')
+    t1 = core_attrs.Time('2012/01/01', '2013/1/2')
     ans1 = jsoc.jsoc.and_(a1 | a2, t1)
     assert isinstance(ans1, AttrOr)
     assert isinstance(ans1.attrs[0], AttrAnd)
@@ -40,8 +38,8 @@ def test_mediumquery():
 def test_complexquery():
     a1 = attrs.Series('foo1')
     a2 = attrs.Series('foo2')
-    t1 = vso_attrs.Time('2012/01/01', '2013/1/2')
-    t2 = vso_attrs.Time('2012/01/01', '2013/1/3')
+    t1 = core_attrs.Time('2012/01/01', '2013/1/2')
+    t2 = core_attrs.Time('2012/01/01', '2013/1/3')
     ans1 = jsoc.jsoc.and_(a1 | a2, t1 | t2)
     assert isinstance(ans1.attrs[0], AttrOr)
     assert isinstance(ans1.attrs[0].attrs[0], AttrAnd)
@@ -50,11 +48,11 @@ def test_complexquery():
 
 def test_wavelength_error():
     with pytest.raises(TypeError):
-        w1 = attrs.Wavelength('wobble')
+        attrs.Wavelength('wobble')
     with pytest.raises(TypeError):
-        w1 = attrs.Wavelength(3.24)
+        attrs.Wavelength(3.24)
     with pytest.raises(TypeError):
-        w1 = attrs.Wavelength((3, 3))
+        attrs.Wavelength((3, 3))
 
 
 def test_wave_self():
