@@ -1,8 +1,6 @@
 import os
 import tempfile
-from unittest import mock
 
-import pandas as pd
 import pytest
 from parfive import Results
 
@@ -15,7 +13,7 @@ import sunpy.data.test
 import sunpy.map
 import sunpy.net.attrs as a
 from sunpy.net.jsoc import JSOCClient, JSOCResponse
-from sunpy.util.exceptions import SunpyDeprecationWarning, SunpyUserWarning
+from sunpy.util.exceptions import SunpyUserWarning
 
 
 @pytest.fixture
@@ -78,18 +76,6 @@ def test_post_pass(client):
     assert tmpresp['method'] == 'url'
 
 
-@pytest.mark.remote_data
-def test_build_table(client):
-    responses = client.search(
-        a.Time('2020/1/1T00:00:00', '2020/1/1T00:00:45'),
-        a.jsoc.Series('hmi.M_45s'))
-    table = responses.build_table()
-    assert isinstance(table, astropy.table.Table)
-
-    columns = ['T_REC', 'TELESCOP', 'INSTRUME', 'WAVELNTH', 'CAR_ROT']
-    assert columns == table._display_table.colnames
-
-
 def test_show(client):
     jdict = {'TELESCOP': ['SDO/HMI', 'SDO/AIA'], 'CAR_ROT': [2145, 2145]}
     responses = JSOCResponse(astropy.table.Table(jdict))
@@ -128,7 +114,7 @@ def test_post_notify_fail(client):
 
 @pytest.mark.remote_data()
 def test_post_wave_series(client):
-    with pytest.raises(TypeError):
+    with pytest.raises(TypeError, match="The series hmi.M_45s does not support wavelength attribute."):
         client.search(
             a.Time('2020/1/1T00:00:00', '2020/1/1T00:00:45'),
             a.jsoc.Series('hmi.M_45s') | a.jsoc.Series('aia.lev1_euv_12s'),
@@ -189,7 +175,8 @@ def test_invalid_query(client):
 def test_lookup_records_errors(client):
     d1 = {'end_time': astropy.time.Time('2020-01-01 01:00:35'),
           'start_time': astropy.time.Time('2020-01-01 00:00:35')}
-    with pytest.raises(ValueError):          # Series must be specified for a JSOC Query
+    # Series must be specified for a JSOC Query
+    with pytest.raises(ValueError):
         client._lookup_records(d1)
 
     d1.update({'series': 'aia.lev1_euv_12s'})
@@ -200,7 +187,8 @@ def test_lookup_records_errors(client):
 
     d1['keys'] = 'T_OBS'
     d1.update({'primekey': {'foo': 'bar'}})
-    with pytest.raises(ValueError):          # Unexpected PrimeKeys were passed.
+    # Unexpected PrimeKeys were passed.
+    with pytest.raises(ValueError):
         client._lookup_records(d1)
 
     del d1['primekey']
@@ -210,8 +198,9 @@ def test_lookup_records_errors(client):
     with pytest.raises(TypeError):
         client._lookup_records(d1)
 
+    # Unexpected Segments were passed.
     d1.update({'segment': 'foo'})
-    with pytest.raises(ValueError):          # Unexpected Segments were passed.
+    with pytest.raises(ValueError):
         client._lookup_records(d1)
 
     del d1['segment']
@@ -296,17 +285,6 @@ def test_make_recordset(client):
     assert client._make_recordset(**d1) == exp
 
 
-@pytest.mark.remote_data
-def test_search_metadata(client):
-    with pytest.raises(SunpyDeprecationWarning):
-        metadata = client.search_metadata(a.Time('2020-01-01T00:00:00', '2020-01-01T00:02:00'),
-                                          a.jsoc.Series('aia.lev1_euv_12s'), a.Wavelength(304*u.AA))
-        assert isinstance(metadata, pd.DataFrame)
-        assert metadata.shape == (11, 176)
-        for i in metadata.index.values:
-            assert (i.startswith('aia.lev1_euv_12s') and i.endswith('[304]'))
-
-
 @pytest.mark.remote_data
 def test_request_data_error(client):
     responses = client.search(
@@ -411,28 +389,6 @@ def test_can_handle_query_no_series(client):
     assert client._can_handle_query(a.jsoc.Series("hmi.M_45s"))
 
 
-@pytest.mark.remote_data
-def test_max_parallel_connections(client):
-    responses = client.search(
-        a.Time('2020/1/1T1:00:36', '2020/1/1T01:01:38'),
-        a.jsoc.Series('hmi.M_45s'), a.jsoc.Notify('jsoc@cadair.com'),
-        a.jsoc.Protocol("as-is"))
-
-    path = tempfile.mkdtemp()
-
-    with mock.patch(
-        "parfive.Downloader.download",
-        new_callable=mock.MagicMock
-    ) as download:
-
-        download.side_effect = ["Mocked Downloader"]
-
-        with pytest.warns(SunpyUserWarning):
-            client.fetch(responses, path=path, max_conn=5, max_splits=5)
-
-    assert download.called
-
-
 def test_jsoc_attrs(client):
     attrs = client.load_jsoc_values()
     assert a.jsoc.Series in attrs.keys()
@@ -461,7 +417,7 @@ def test_jsoc_cutout_attrs(client):
     req = client.request_data(q, method='url', protocol='fits')
     req.wait()
     assert req.status == 0
-    files = client.get_request(req, max_conn=2)
+    files = client.get_request(req)
     assert len(files) == 6
     m = sunpy.map.Map(files, sequence=True)
     assert m.all_maps_same_shape()
@@ -473,5 +429,37 @@ def test_row_and_warning(mocker, client, jsoc_response_double):
     request_data = mocker.patch("sunpy.net.jsoc.jsoc.JSOCClient.request_data")
     with pytest.warns(SunpyUserWarning):
         client.fetch(jsoc_response_double[0], sleep=0)
-
     assert request_data.called_once_with(jsoc_response_double[0].as_table())
+
+
+@pytest.mark.remote_data
+def test_check_request_keywords(client):
+    responses = client.search(
+        a.Time('2020/1/1T1:00:36', '2020/1/1T01:00:38'),
+        a.jsoc.Series('hmi.M_45s'), a.jsoc.Keyword("QUALITY") == 1)
+    assert len(responses) == 0
+
+    responses = client.search(
+        a.Time('2020/1/1T1:00:36', '2020/1/1T01:00:38'),
+        a.jsoc.Series('hmi.M_45s'), a.jsoc.Keyword("QUALITY") == 0)
+    assert len(responses) == 1
+
+    responses = client.search(
+        a.Time('2020/1/1T1:00:36', '2020/1/1T01:00:38'),
+        a.jsoc.Series('hmi.M_45s'), a.jsoc.Keyword("QUALITY") < 2)
+    assert len(responses) == 1
+
+    with pytest.raises(ValueError, match="Keyword: 'EXPTIME' is not supported by series:"):
+        client.search(
+            a.Time('2020/1/1T1:00:36', '2020/1/1T01:00:38'),
+            a.jsoc.Series('hmi.M_45s'), a.jsoc.Keyword("EXPTIME") < 2)
+
+    responses = client.search(
+        a.Time('2020/1/1T1:00:36', '2020/1/1T01:00:38'),
+        a.jsoc.Series('aia.lev1_euv_12s'), a.jsoc.Keyword("QUALITY") < 2, a.jsoc.Keyword("EXPTIME") < 2)
+    assert len(responses) == 0
+
+    responses = client.search(
+        a.Time('2020/1/1T1:00:36', '2020/1/1T01:00:38'),
+        a.jsoc.Series('aia.lev1_euv_12s'), a.jsoc.Keyword("QUALITY") < 2, a.jsoc.Keyword("EXPTIME") > 2)
+    assert len(responses) == 7
