@@ -1,26 +1,32 @@
-"""XML helper functions"""
-
-from __future__ import absolute_import, division, print_function
-
-from xml.dom.minidom import parseString #pylint: disable=E0611,F0401
+"""
+This module provides XML helper functions.
+"""
+from xml.dom.minidom import parseString
 
 __all__ = ['NotTextNodeError', 'xml_to_dict', 'node_to_dict', 'get_node_text']
 
-#
-# Converting XML to a Dictionary
-# Author: Christoph Dietze
-# URL   : http://code.activestate.com/recipes/116539/
-#
+
 class NotTextNodeError(Exception):
     pass
 
+
 def xml_to_dict(xmlstring):
     """
-    Converts an XML string to a Python dictionary
+    Converts an XML string to a Python dictionary.
 
-    .. Warning::
+    .. warning::
         This method does not support multiple inner nodes of the same name but
-        with different values.  It always takes the last value.
+        with different values. It always takes the last value.
+
+    Parameters
+    ----------
+    xmlstring : `str`
+        A `str` of xml content.
+
+    Returns
+    -------
+    `dict`:
+        The string xml input as a dictionary.
 
     Examples
     --------
@@ -34,24 +40,38 @@ def xml_to_dict(xmlstring):
     gives you the dict::
 
        {u'outer': {u'inner': u'two'}}
+
+    References
+    ----------
+    * https://github.com/ActiveState/code/tree/master/recipes/Python/116539_turn_structure_XMLdocument
     """
     return node_to_dict(parseString(xmlstring))
 
+
 def node_to_dict(node):
     """
-    node_to_dict() scans through the children of node and makes a dictionary
-    from the content.
+    Scans through the children of the node and makes a dictionary from the
+    content.
 
     Three cases are differentiated:
 
     1. If the node contains no other nodes, it is a text-node and
-       {nodeName: text} is merged into the dictionary.
-    2. If the node has the attribute "method" set to "true", then it's children
+       ``{nodeName: text}`` is merged into the dictionary.
+    2. If the node has the attribute ``method`` set to ``true``, then it's children
        will be appended to a list and this list is merged to the dictionary in
-       the form: {nodeName:list}.
-    3. Else, node_to_dict() will call itself recursively on the nodes children
-       (merging {nodeName: node_to_dict()} to the dictionary).
+       the form: ``{nodeName:list}``.
+    3. Else, will call itself recursively on the nodes children
+       (merging ``{nodeName: node_to_dict()}`` to the dictionary).
 
+    Parameters
+    ----------
+    node : `xml.etree.ElementTree.Element`
+        A XML element node.
+
+    Returns
+    -------
+    `dict`:
+        The XML element node as a dictionary.
     """
     dic = {}
     for n in node.childNodes:
@@ -59,12 +79,12 @@ def node_to_dict(node):
             continue
         if n.getAttribute("multiple") == "true":
             # node with multiple children: put them in a list
-            l = []
+            alist = []
             for c in n.childNodes:
                 if c.nodeType != n.ELEMENT_NODE:
                     continue
-                l.append(node_to_dict(c))
-                dic.update({n.nodeName: l})
+                alist.append(node_to_dict(c))
+                dic.update({n.nodeName: alist})
             continue
 
         try:
@@ -79,10 +99,23 @@ def node_to_dict(node):
         continue
     return dic
 
+
 def get_node_text(node):
     """
-    scans through all children of node and gathers the text. if node has
-    non-text child-nodes, then NotTextNodeError is raised.
+    Scans through all children of `~xml.etree.ElementTree.Element` node and
+    gathers the text.
+
+    If node has non-text child-nodes, then `~sunpy.util.xml.NotTextNodeError` is raised.
+
+    Parameters
+    ----------
+    node : `xml.etree.ElementTree.Element`
+        A XML element node.
+
+    Returns
+    -------
+    `str`:
+        The `str` context of the XML element node.
     """
     t = ""
     for n in node.childNodes:
