@@ -12,4 +12,4 @@ The following colormaps are provided by this module.
 from sunpy.visualization.colormaps.cm import *
 
 for cmname in cmlist.keys():
-    __doc__ += f"\n* '`~sunpy.visualisation.colormaps.{cmname}`'\n"
+    __doc__ += f"\n* '{cmname}'\n"
