@@ -5,6 +5,7 @@ import astropy.units as u
 
 import sunpy.visualization.colormaps as cm
 import sunpy.visualization.colormaps.color_tables as ct
+from sunpy.tests.helpers import figure_test
 
 
 # Checks that colormaps are imported by MPL
@@ -36,3 +37,8 @@ def test_invalid_wavelengths(f, match):
     # Check that accessing non-existent color table values raises a ValueError
     with pytest.raises(ValueError, match=match):
         f(-100*u.m)
+
+
+@figure_test
+def test_cmap_visual():
+    cm.show_colormaps()
